@@ -4,7 +4,7 @@
 #
 # Created by Idel Fuschini 
 # Date: 15/10/11
-# Site: http://www.idelfuschini.it
+# Site: http://www.apachemobilefilter.org
 # Mail: idel.fuschini@gmail.com
 
 
@@ -33,7 +33,7 @@ package Apache2::AMFDetectRightFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "3.40a";
+  $VERSION= "3.50";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -204,7 +204,7 @@ sub loadConfigFile {
 		}
 		if ($ENV{AMFDeepParse}) {
 			$deepSearch=$ENV{AMFDeepParse};
-			$CommonLib->printLog("RestMode is: $deepSearch");			
+			$CommonLib->printLog("AMFDeepParse is: $deepSearch");			
 		} else {
 				$CommonLib->printLog("AMFDeepParse  is not setted the default value is 3");			   
 		}
@@ -258,10 +258,15 @@ sub loadConfigFile {
 			if (-e "$fileDetectRight") {
 					$CommonLib->printLog("Start loading  DetectRightAMF.xml");
 					if (open (IN,"$fileDetectRight")) {
-						while (<IN>) {
-							 $r_id=parseDetectRightFile($_,$r_id);
-							 
-						}
+                                         	      my $filesize= -s $fileDetectRight;
+                                                      read (IN,my $string_file,$filesize);
+                                                      close IN;
+                                                      $string_file =~ s/\n//g;
+                                                      $string_file =~ s/>/>\n/g;
+                                                      my @rows = split(/\n/, $string_file); 
+                                                      foreach my $row (@rows){
+                                                            $r_id=parseDetectRightFile($row,$r_id);
+                                                      } 
 						close IN;
 					} else {
 					    $CommonLib->printLog("Error open file:$fileDetectRight");
@@ -361,9 +366,7 @@ sub IdentifyUAMethod {
   {
       my $dummy=$ArrayUAType{$pair};
       if ($Array_id{$dummy}) {
-         if ($id_find) {
-           my $dummy2="";
-         } else {
+         if (!$id_find) {
            $id_find=$Array_id{$dummy};
          }
       }
@@ -373,15 +376,15 @@ sub IdentifyUAMethod {
 sub IdentifyPCUAMethod {
   my ($UserAgent) = @_;
   my $ind=0;
-  my $id_find="";
+  my $id_find="none";
   my $pair;
   my $length=0;
   foreach $pair (sort keys %PCArray) {
-	if ($UserAgent =~ m/$pair/) {
+	if ($UserAgent =~ m/$pair/ && $id_find eq 'none') {
 		$id_find=$PCArray{$pair};
 	}
   }
-  if ($id_find) {} else {$id_find="";};
+  if (!$id_find) {$id_find="";}
   return $id_find;
 }
 sub callparseDetectRightFile {
@@ -528,6 +531,7 @@ sub handler {
 
     }    
 
+    $user_agent=lc($user_agent);
 	if ($user_agent =~ m/blackberry/i) {	 
 		$user_agent=substr($user_agent,index($user_agent,'blackberry'));
 		$mobile=1;
@@ -538,7 +542,6 @@ sub handler {
 	}
     my $cookie = $f->headers_in->{Cookie} || '';
     $id=$CommonLib->readCookie($cookie);
-    $user_agent=lc($user_agent);
     ($user_agent,$version)=$CommonLib->androidDetection($user_agent);
     if ($id eq ""){
                   if ($user_agent) {
@@ -552,7 +555,7 @@ sub handler {
 						if ($mobile==0) {
 							$user_agent=$CommonLib->botDetection($user_agent);    
                                                         $realPCbrowser=IdentifyPCUAMethod($user_agent);
-                                                        if ($realPCbrowser ne "") {
+                                                        if ($realPCbrowser ne "none") {
                                                             $id="generic_web_browser";
                                                             $mobile=-1;
                                                         }
@@ -584,10 +587,14 @@ sub handler {
 				  }	
      }                        
      if ($id ne "") {
-	      	     #
+                     #
 	      	     #  device detected 
 	      	     #
-	      	     my $var=$memd->get("$id");
+                     if ($realPCbrowser ne 'none') {
+                        $id=$realPCbrowser;
+                     }
+
+	      	     my $var=$memd->get("DR_$id");
 		         if ($var) {
 					my @pairs = split(/&/, $var);
 					my $param_tofound;
@@ -606,7 +613,11 @@ sub handler {
                                     } else {
                                           %ArrayCapFound=FallBack($id);
                                     }
-					%ArrayCapFound=FallBack($id);
+                                    if ($realPCbrowser ne 'none') {
+                                          $id=$realPCbrowser;
+                                          $ArrayCapFound{'is_wireless_device'}='false';
+                                          $ArrayCapFound{'device_claims_web_support'}='true';
+                                    }
 					foreach $capability2 (sort keys %ArrayCapFound) {
 						$variabile2="$variabile2$capability2=$ArrayCapFound{$capability2}&";
 						my $upper=uc($capability2);
@@ -614,13 +625,10 @@ sub handler {
 						$f->pnotes("$capability2" => $ArrayCapFound{$capability2});
 					}
                                     
-                                    if ($realPCbrowser ne 'none') {
-                                          $id=$realPCbrowser;
-                                    }
                                     $variabile2="id=$id&$variabile2";
 				    $f->subprocess_env("AMF_ID" => $id);
                                     $f->pnotes('id' => $id);
-				    $memd->set("$id",$variabile2);
+      				    $memd->set("DR_$id",$variabile2);
 			}
 			if ($cookiecachesystem eq "true") {
 						$f->err_headers_out->set('Set-Cookie' => "amf=$id; path=/;");	
