@@ -4,7 +4,7 @@
 #
 # Created by Idel Fuschini 
 # Date: 01/08/10
-# Site: http://www.idelfuschini.it
+# Site: http://www.apachemobilefilter.org
 # Mail: idel.fuschini@gmail.com
 
 
@@ -32,7 +32,7 @@ package Apache2::AMFWURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "3.40a";
+  $VERSION= "3.50";
   my $CommonLib = new Apache2::AMFCommonLib ();
  
   my %Capability;
@@ -594,9 +594,7 @@ sub IdentifyUAMethod {
   {
       my $dummy=$ArrayUAType{$pair};
       if ($Array_id{$dummy}) {
-         if ($id_find) {
-           my $dummy2="";
-         } else {
+         if (!$id_find) {
            $id_find=$Array_id{$dummy};
          }
       }
@@ -689,7 +687,7 @@ sub handler {
     	  }
 
     }
-
+        $user_agent=lc($user_agent);
 	if ($user_agent =~ m/blackberry/i) {	 
 		$user_agent=substr($user_agent,index($user_agent,'blackberry'));
 		$mobile=1;
@@ -700,7 +698,6 @@ sub handler {
 	}
     my $cookie = $f->headers_in->{Cookie} || '';
     $id=$CommonLib->readCookie($cookie);
-    $user_agent=lc($user_agent);
     ($user_agent,$version)=$CommonLib->androidDetection($user_agent);
 
     if ($cacheSystem->restore( 'wurfl-ua', $user_agent )) {
@@ -765,8 +762,8 @@ sub handler {
 					}
 					$cacheSystem->store( 'wurfl-ua', $user_agent, $id);
 				  }	
-		}                        
-		if ($id ne "") {
+     }                        
+     if ($id ne "") {
 	      	     #
 	      	     #  device detected 
 	      	     #
